A wrapper of FRAUDAR algorithm
==============================

|GPLv3| |Build Status| |Maintainability| |Test Coverage| |Release|

|Logo|

This package implements a wrapper of
`FRAUDAR <https://bhooi.github.io/projects/fraudar/index.html>`__
algorithm to provide APIs defined in `Review Graph Mining
project <https://rgmining.github.io/>`__.

Installation
------------

Use ``pip`` to install this package.

.. code:: shell

    $pip install --upgrade rgmining-fraudar

License
-------

This software is released under The GNU General Public License Version
3, see
`COPYING <https://github.com/rgmining/fraudar/blob/master/COPYING>`__
for more detail.

The original FRAUDAR source code is made by `Bryan
Hooi <https://bhooi.github.io/index.html>`__, `Hyun Ah
Song <http://www.cs.cmu.edu/~hyunahs/>`__, `Alex
Beutel <http://alexbeutel.com/>`__, `Neil
Shah <http://nshah.net/>`__, `Kijung
Shin <https://kijungs.github.io/>`__, and `Christos
Faloutsos <http://www.cs.cmu.edu/~christos/>`__, and licensed under
`Apache License, Version 2.0 <LICENSE-2.0>`__. It is available at
https://bhooi.github.io/projects/fraudar/index.html.

.. |GPLv3| image:: https://img.shields.io/badge/license-GPLv3-blue.svg
   :target: https://www.gnu.org/copyleft/gpl.html
.. |Build Status| image:: https://github.com/rgmining/fraudar/actions/workflows/python-lib.yaml/badge.svg
   :target: https://github.com/rgmining/fraudar/actions/workflows/python-lib.yaml
.. |Maintainability| image:: https://api.codeclimate.com/v1/badges/4c4c3df79b33f65b77cd/maintainability
   :target: https://codeclimate.com/github/rgmining/fraudar/maintainability
.. |Test Coverage| image:: https://api.codeclimate.com/v1/badges/4c4c3df79b33f65b77cd/test_coverage
   :target: https://codeclimate.com/github/rgmining/fraudar/test_coverage
.. |Release| image:: https://img.shields.io/badge/release-0.7.0-brightgreen.svg
   :target: https://pypi.org/project/rgmining-fraudar/
.. |Logo| image:: https://rgmining.github.io/fraudar/_static/image.png
   :target: https://rgmining.github.io/fraudar/
